SemanticWrappingInfo class

Information about semantic wrapping of a widget

Constructors

SemanticWrappingInfo({required bool hasSemantics, required bool isExcluded})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasSemantics → bool
final
isExcluded → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited